# CorsacLib
The python package that manages logs for Corsac.

## Table of Contents
- [Introduction](#introduction)
- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)

## Introduction

CorsacLib is a managed logger that utilizes post quantum cryptography to enable users to safely store and verify data.
The crypto libraries used are:
- [sphincs+](https://sphincs.org/)
- AES-256-CBC

## Installation

CorsacLib can be installed via [PyPI](https://pypi.org/project/corsaclib/).

- Run `pip install corsaclib`
- Export a `config.json` or `config.yml` file from Corsac KMS.

## Usage
All you need is a config generated by Corsac KMS and an application that requires logging.
To initialize the logger you can do the following:
```python
from corsaclib import LogHandler

logHandler = LogHandler(configfile="config.yml", filetype="yaml", directory="logs/", create_directory=False)

"""
### Arguments

configfile : str
    The path to the configuration file.
filetype : FileType
    The type of the configuration file.
    json or yaml.
deleteconfig : bool
    Whether the configuration file should be scrubbed after loading.
directory : str
    The directory where the logs are stored.
create_directory : bool
    Whether the directory should be created.
logchain_size : int
    The maximum amount of logs that will be stored in one file.
"""
```

To start logging, run the following:
```python
logHandler.log({"user":"dev-umla", "action":"restarted firmware"})

"""
### Parameters
        
log : dict
    The log to write.
join_queue : bool
    Whether to process all items in the log queue.
    A blocking operation.
"""
```


## Contributing

Contributions to this project are welcome. To contribute, please follow these guidelines:

1. Fork the repository.
2. Create a new branch for your feature or bug fix.
3. Make your changes and commit them.
4. Push your changes to your forked repository.
5. Submit a pull request.

## License

This project is licensed under the [MIT License](LICENSE).